==> visiscript_src_0.3.2.tar.gz: visiscript-0.3.2/mymledit.h <==
/**************************************************************************
 *
 *	project				 : VisiScript
 *
 *	copyright            : (C) 2002 by Michael Neuroth
 *
 * ------------------------------------------------------------------------
 *
 *  $Source$
 *
 *  $Revision$
 *
 *	$Log$
 *
 ***************************************************************************/
/*********************************************************************************
 *																				 *
 * This file is part of the VisiScript package (a frontend for script languages) *
 *																				 *
 * Copyright (C) 2002 by Michael Neuroth.										 *
 *                                                                               *
 * This program is free software; you can redistribute it and/or modify			 *
 * it under the terms of the GNU General Public License as published by    		 *
 * the Free Software Foundation; either version 2 of the License, or             *
 * (at your option) any later version.                                           *
 *                                                                               *
 ********************************************************************************/

#ifndef _MYMLEDIT_H
#define _MYMLEDIT_H

#include <qmultilineedit.h>
#include <qstring.h>

class MyQMultiLineEdit : public QMultiLineEdit
{
	Q_OBJECT

public:
	MyQMultiLineEdit( QWidget * parent=0, const char * name=0 );
	~MyQMultiLineEdit();

	bool hasMarkedTxt();
	QString markedTxt();
};

#endif

==> visiscript_src_0.4.3.tar.gz: visiscript-0.4.3/mymledit.h <==
/**************************************************************************
 *
 *	project				 : VisiScript
 *
 *	copyright            : (C) 2002 by Michael Neuroth
 *
 * ------------------------------------------------------------------------
 *
 *  $Source: E:/home/cvsroot/visiscript/mymledit.h,v $
 *
 *  $Revision: 1.4 $
 *
 *	$Log: mymledit.h,v $
 *	Revision 1.4  2005/11/27 16:23:04  Michael
 *	improved compile support for all platforms
 *	
 *	Revision 1.3  2005/11/20 16:24:06  Michael
 *	added comment for the zaurus platform
 *	
 *	Revision 1.2  2005/11/14 16:23:20  Michael
 *	simulate mouse-double-click event for zaurus
 *	
 *	Revision 1.1.1.1  2005/11/06 11:34:15  Michael
 *	initial checkin of version 0.3.2
 *	
 *
 ***************************************************************************/
/*********************************************************************************
 *																				 *
 * This file is part of the VisiScript package (a frontend for script languages) *
 *																				 *
 * Copyright (C) 2002 by Michael Neuroth.										 *
 *                                                                               *
 * This program is free software; you can redistribute it and/or modify			 *
 * it under the terms of the GNU General Public License as published by    		 *
 * the Free Software Foundation; either version 2 of the License, or             *
 * (at your option) any later version.                                           *
 *                                                                               *
 ********************************************************************************/

#ifndef _MYMLEDIT_H
#define _MYMLEDIT_H

#include <qmultilineedit.h>
#include <qstring.h>

class QMouseEvent;

class MyQMultiLineEdit : public QMultiLineEdit
{
	Q_OBJECT

public:
	MyQMultiLineEdit( QWidget * parent=0, const char * name=0 );
	virtual ~MyQMultiLineEdit();

	bool hasMarkedTxt();
	QString markedTxt();
};

// Zaurus uses a modified implementation to simulat doubleClicked() signal !
class ZMyQMultiLineEdit : public MyQMultiLineEdit
{
	Q_OBJECT

public:
	ZMyQMultiLineEdit( QWidget * parent=0, const char * name=0 );
	virtual ~ZMyQMultiLineEdit();

protected:
	void mouseDoubleClickEvent( QMouseEvent * m );

signals:
    void doubleClicked( int parag, int index );
};

#endif
